@@ -12,7 +12,7 @@ use Tags::HTML::Messages;
 
 Readonly::Array our @FORM_METHODS => qw(post get);
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
@@ -107,6 +107,7 @@ sub _process {
 		['a', 'type', 'text'],
 		['a', 'name', $username_id],
 		['a', 'id', $username_id],
+		['a', 'autofocus', 'autofocus'],
 		['e', 'input'],
 		['e', 'p'],
 
@@ -435,7 +436,7 @@ Returns undef.
  #       <label for="username">
  #       </label>
  #       User name
- #       <input type="text" name="username" id="username">
+ #       <input type="text" name="username" id="username" autofocus="autofocus">
  #       </input>
  #     </p>
  #     <p>
@@ -527,6 +528,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
